PORT = 1978
HOST = "localhost"

CHEROKEE_PATH     = "../cherokee/cherokee"
CHEROKEE_MODS     = "/usr/lib/cherokee"

STRACE_PATH       = "/usr/bin/strace"
VALGRIND_PATH     = "/usr/bin/valgrind"
PHPCGI_PATH       = "/usr/lib/cgi-bin/php4"
PYTHON_PATH       = "/usr/bin/python2.4"

SSL_CERT_FILE     = "/etc/cherokee/ssl/cherokee.pem"
SSL_CERT_KEY_FILE = "/etc/cherokee/ssl/cherokee.pem"
SSL_CA_FILE       = "/etc/cherokee/ssl/cherokee.pem"

PHP_FCGI_PORT     = 1979
